@@ -11,17 +11,21 @@ def SendAllCoin(api: DecimalAPI, wallet: Wallet, receiver: str, coin_name: str,
     try:
         wallet_data = json.loads(api.get_address(wallet.get_address()))
         balance = '0'
+        denom = 'del'
+
+        if (options.get('denom') is not None):
+            denom = options['denom']
+
         if wallet_data["ok"]:
             balance = wallet_data["result"]["address"]["balance"][coin_name]
-            print(wallet_data["result"]["address"]["balance"])
+
         balance = int(balance) * pow(10, -18)
 
-        tx = SendCoinTransaction(wallet.get_address(), receiver, coin_name, balance) #transaction for calculation commission
-        wallet_balance = balance
-        if(coin_name == 'del' or coin_name == 'tdel'):
-            wallet_balance = wallet_balance -  api.estimate_tx_fee(tx, wallet, options)
+        if denom is coin_name:
+            tx = SendCoinTransaction(wallet.get_address(), receiver, coin_name, balance) #transaction for calculation commission
+            balance = balance - api.estimate_tx_fee(tx, wallet, options)
 
-        tx1 = SendCoinTransaction(wallet.get_address(), receiver, coin_name, wallet_balance)
+        tx1 = SendCoinTransaction(wallet.get_address(), receiver, coin_name, balance - 0.00001)
 
         return api.send_tx(tx1, wallet, options)
 
